==> fantacalciobazar_0.5.3.tar.gz: fantacalciobazar/tab_calciatori.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

$calciatori = file("$percorso_cartella_voti/calciatori.txt");
$num_calciatori = count($calciatori);

if ($formato_pda == "SI") echo "<table width=3 border=1 cellspacing=0 cellpadding=1 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>__________Nome__________</td>
<td><font size=-2>Ruolo</font></td>
<td>&nbsp;</td></tr>";
else echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td>&nbsp;</td></tr>";

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {

$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = togli_acapo($numero);
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = togli_acapo($nome);
$nome = preg_replace("/\"/","",$nome);
$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$s_ruolo = togli_acapo($s_ruolo);
$ruolo = $s_ruolo;
if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo = $considera_fantasisti_come;
if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";

if ($ruolo == $ruolo_guarda or $ruolo_guarda == "tutti") {
echo"<tr><td align=\"center\"><a href=\"stat_calciatore.php?num_calciatore=$numero&amp;ruolo_guarda=$ruolo_guarda&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">$numero</a></td>
<td>$nome</td>
<td>$ruolo</td>
<td>";
if ($formato_pda == "SI") {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"offerta.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"num_calciatore\" value=\"$numero\">
<input type=\"submit\" value=\"offri\">
</form>";
} # fine if ($formato_pda == "SI")
else echo "<a href=\"offerta.php?num_calciatore=$numero&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">offri</a>";
echo "</td>
</tr>";
} # fine if ($ruolo == $ruolo_guarda or ...)

} # fine for $num1
echo "</table>";

echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";

} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.5.tar.gz: fantacalciobazar/tab_calciatori.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

$calciatori = file("$percorso_cartella_voti/calciatori.txt");
$num_calciatori = count($calciatori);

if ($formato_pda == "SI") echo "<table width=3 border=1 cellspacing=0 cellpadding=1 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>__________Nome__________</td>
<td><font size=-2>Ruolo</font></td>
<td>&nbsp;</td></tr>";
else echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td>&nbsp;</td></tr>";

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {

$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = togli_acapo($numero);
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = togli_acapo($nome);
$nome = preg_replace("/\"/","",$nome);
$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$s_ruolo = togli_acapo($s_ruolo);
$ruolo = $s_ruolo;
if ($num_colonna_attributo_fantasista) $attr_fantasista = $dati_calciatore[($num_colonna_attributo_fantasista-1)];
else $attr_fantasista = 0;
if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo = $considera_fantasisti_come;
if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
if ($considera_fantasisti_come == "F" and $attr_fantasista) $ruolo = "F";

if ($ruolo == $ruolo_guarda or $ruolo_guarda == "tutti") {
if ($attr_fantasista and $ruolo != "F") $ruolo .= "<small>(F)</small>";
echo"<tr><td align=\"center\"><a href=\"stat_calciatore.php?num_calciatore=$numero&amp;ruolo_guarda=$ruolo_guarda&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">$numero</a></td>
<td>$nome</td>
<td>$ruolo</td>
<td>";
if ($formato_pda == "SI") {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"offerta.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"num_calciatore\" value=\"$numero\">
<input type=\"submit\" value=\"offri\">
</form>";
} # fine if ($formato_pda == "SI")
else echo "<a href=\"offerta.php?num_calciatore=$numero&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">offri</a>";
echo "</td>
</tr>";
} # fine if ($ruolo == $ruolo_guarda or ...)

} # fine for $num1
echo "</table>";

echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";

} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
